@@ -26,6 +26,7 @@
 #include <gtk/gtk.h>
 
 #include "photos-gom-miner.h"
+#include "photos-tracker-miner-files-index.h"
 
 G_BEGIN_DECLS
 
@@ -34,11 +35,15 @@ G_DECLARE_FINAL_TYPE (PhotosApplication, photos_application, PHOTOS, APPLICATION
 
 GApplication          *photos_application_new                    (void);
 
+TrackerMinerFilesIndex *photos_application_dup_miner_files_index (PhotosApplication *self);
+
 gboolean               photos_application_get_empty_results      (PhotosApplication *self);
 
 GomMiner              *photos_application_get_miner              (PhotosApplication *self,
                                                                   const gchar *provider_type);
 
+const gchar           *photos_application_get_miner_files_name   (PhotosApplication *self);
+
 GList                 *photos_application_get_miners_running     (PhotosApplication *self);
 
 gint                   photos_application_get_scale_factor       (PhotosApplication *self);
