@@ -71,7 +71,11 @@ struct _PhotosBaseItemClass
   void        (*open)                       (PhotosBaseItem *self, GtkWindow *parent, guint32 timestamp);
   void        (*refresh_icon)               (PhotosBaseItem *self);
   void        (*set_favorite)               (PhotosBaseItem *self, gboolean favorite);
-  void        (*trash)                      (PhotosBaseItem *self);
+  void        (*trash_async)                (PhotosBaseItem *self,
+                                             GCancellable *cancellable,
+                                             GAsyncReadyCallback callback,
+                                             gpointer user_data);
+  gboolean    (*trash_finish)               (PhotosBaseItem *self, GAsyncResult *res, GError **error);
   void        (*update_type_description)    (PhotosBaseItem *self);
 
   /* signals */
@@ -333,7 +337,14 @@ void                photos_base_item_set_default_app_name    (PhotosBaseItem *se
 
 void                photos_base_item_set_favorite            (PhotosBaseItem *self, gboolean favorite);
 
-void                photos_base_item_trash                   (PhotosBaseItem *self);
+void                photos_base_item_trash_async             (PhotosBaseItem *self,
+                                                              GCancellable *cancellable,
+                                                              GAsyncReadyCallback callback,
+                                                              gpointer user_data);
+
+gboolean            photos_base_item_trash_finish            (PhotosBaseItem *self,
+                                                              GAsyncResult *res,
+                                                              GError **error);
 
 void                photos_base_item_unmark_busy             (PhotosBaseItem *self);
 
