@@ -388,6 +388,8 @@ photos_embed_load_started (PhotosEmbed *self, PhotosBaseItem *item)
 static void
 photos_embed_fullscreen_changed (PhotosModeController *mode_cntrlr, gboolean fullscreen, gpointer user_data)
 {
+  PhotosEmbed *self = PHOTOS_EMBED (user_data);
+  gtk_widget_set_visible (self->toolbar, !fullscreen);
 }
 
 
@@ -796,7 +798,6 @@ static void
 photos_embed_init (PhotosEmbed *self)
 {
   GApplication *app;
-  GList *windows;
   PhotosSearchbar *searchbar;
   PhotosSearchContextState *state;
   gboolean querying;
@@ -812,10 +813,7 @@ photos_embed_init (PhotosEmbed *self)
 
   self->extension_point = g_io_extension_point_lookup (PHOTOS_TRACKER_CONTROLLER_EXTENSION_POINT_NAME);
 
-  self->toolbar = photos_main_toolbar_new ();
   photos_main_toolbar_set_stack (PHOTOS_MAIN_TOOLBAR (self->toolbar), GTK_STACK (self->stack));
-  windows = gtk_application_get_windows (GTK_APPLICATION (app));
-  gtk_window_set_titlebar (GTK_WINDOW (windows->data), self->toolbar);
   searchbar = photos_main_toolbar_get_searchbar (PHOTOS_MAIN_TOOLBAR (self->toolbar));
   g_signal_connect_swapped (searchbar, "activate-result", G_CALLBACK (photos_embed_activate_result), self);
 
@@ -825,6 +823,7 @@ photos_embed_init (PhotosEmbed *self)
   self->overview = photos_view_container_new (PHOTOS_WINDOW_MODE_OVERVIEW, _("Photos"));
   name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (self->overview));
   gtk_stack_add_titled (GTK_STACK (self->stack), self->overview, "overview", name);
+  gtk_container_child_set (GTK_CONTAINER (self->stack), self->overview, "icon-name", "camera-photo-symbolic", NULL);
 
   self->collection_view = photos_view_container_new (PHOTOS_WINDOW_MODE_COLLECTION_VIEW, _("Collection View"));
   gtk_stack_add_named (GTK_STACK (self->stack), self->collection_view, "collection-view");
@@ -832,10 +831,12 @@ photos_embed_init (PhotosEmbed *self)
   self->collections = photos_view_container_new (PHOTOS_WINDOW_MODE_COLLECTIONS, _("Albums"));
   name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (self->collections));
   gtk_stack_add_titled (GTK_STACK (self->stack), self->collections, "collections", name);
+  gtk_container_child_set (GTK_CONTAINER (self->stack), self->collections, "icon-name", "emblem-photos-symbolic", NULL);
 
   self->favorites = photos_view_container_new (PHOTOS_WINDOW_MODE_FAVORITES, _("Favorites"));
   name = photos_view_container_get_name (PHOTOS_VIEW_CONTAINER (self->favorites));
   gtk_stack_add_titled (GTK_STACK (self->stack), self->favorites, "favorites", name);
+  gtk_container_child_set (GTK_CONTAINER (self->stack), self->favorites, "icon-name", "starred-symbolic", NULL);
 
   self->import = photos_view_container_new (PHOTOS_WINDOW_MODE_IMPORT, _("Import"));
   gtk_stack_add_named (GTK_STACK (self->stack), self->import, "import");
@@ -941,6 +942,7 @@ photos_embed_class_init (PhotosEmbedClass *class)
   gtk_widget_class_bind_template_child (widget_class, PhotosEmbed, spinner_box);
   gtk_widget_class_bind_template_child (widget_class, PhotosEmbed, stack);
   gtk_widget_class_bind_template_child (widget_class, PhotosEmbed, stack_overlay);
+  gtk_widget_class_bind_template_child (widget_class, PhotosEmbed, toolbar);
 }
 
 
